Adds a discriminant() function to get the numeric value of enum variants. Also adds
a from_discriminant() function to create unit type enum variants from discriminants.
Derive macro generating an impl for the FromDiscriminant trait for enums. The trait
adds a from_discriminant() function to create unit type enum variants from
discriminants.
Derive macro generating an impl for the IntoDiscriminant trait for enums. The trait
adds a discriminant() function to get the numeric value of enum variants.